Enum frame::prelude::frame_system::pallet::Error
pub enum Error<T> {
InvalidSpecName,
SpecVersionNeedsToIncrease,
FailedToExtractRuntimeVersion,
NonDefaultComposite,
NonZeroRefCount,
CallFiltered,
// some variants omitted
}Expand description
Error for the System pallet
Variants
InvalidSpecName
The name of specification does not match between the current runtime and the new runtime.
SpecVersionNeedsToIncrease
The specification version is not allowed to decrease between the current runtime and the new runtime.
FailedToExtractRuntimeVersion
Failed to extract the runtime version from the new runtime.
Either calling Core_version or decoding RuntimeVersion failed.
NonDefaultComposite
Suicide called when the account has non-default composite data.
NonZeroRefCount
There is a non-zero reference count preventing the account from being purged.
CallFiltered
The origin filter prevent the call to be dispatched.