Struct frame::prelude::frame_system::pallet::Pallet
pub struct Pallet<T>(_);Expand description
The Pallet struct, the main type that implements traits and standalone
functions within the pallet.
Implementations
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn remark(
_origin: <T as Config>::RuntimeOrigin,
remark: Vec<u8, Global>
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn remark( _origin: <T as Config>::RuntimeOrigin, remark: Vec<u8, Global> ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Make some on-chain remark.
Can be executed by every origin.
pub fn set_heap_pages(
origin: <T as Config>::RuntimeOrigin,
pages: u64
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn set_heap_pages( origin: <T as Config>::RuntimeOrigin, pages: u64 ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Set the number of pages in the WebAssembly environment’s heap.
pub fn set_code(
origin: <T as Config>::RuntimeOrigin,
code: Vec<u8, Global>
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn set_code( origin: <T as Config>::RuntimeOrigin, code: Vec<u8, Global> ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Set the new runtime code.
pub fn set_code_without_checks(
origin: <T as Config>::RuntimeOrigin,
code: Vec<u8, Global>
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn set_code_without_checks( origin: <T as Config>::RuntimeOrigin, code: Vec<u8, Global> ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Set the new runtime code without doing any checks of the given code.
pub fn set_storage(
origin: <T as Config>::RuntimeOrigin,
items: Vec<(Vec<u8, Global>, Vec<u8, Global>), Global>
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn set_storage( origin: <T as Config>::RuntimeOrigin, items: Vec<(Vec<u8, Global>, Vec<u8, Global>), Global> ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Set some items of storage.
pub fn kill_storage(
origin: <T as Config>::RuntimeOrigin,
keys: Vec<Vec<u8, Global>, Global>
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn kill_storage( origin: <T as Config>::RuntimeOrigin, keys: Vec<Vec<u8, Global>, Global> ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Kill some items from storage.
pub fn kill_prefix(
origin: <T as Config>::RuntimeOrigin,
prefix: Vec<u8, Global>,
subkeys: u32
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn kill_prefix( origin: <T as Config>::RuntimeOrigin, prefix: Vec<u8, Global>, subkeys: u32 ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Kill all storage items with a key that starts with the given prefix.
NOTE: We rely on the Root origin to provide us the number of subkeys under the prefix we are removing to accurately calculate the weight of this function.
pub fn remark_with_event(
origin: <T as Config>::RuntimeOrigin,
remark: Vec<u8, Global>
) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
pub fn remark_with_event( origin: <T as Config>::RuntimeOrigin, remark: Vec<u8, Global> ) -> Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>
Make some on-chain remark and emit event.
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn account<KArg>(
k: KArg
) -> AccountInfo<<T as Config>::Nonce, <T as Config>::AccountData>where
KArg: EncodeLike<<T as Config>::AccountId>,
pub fn account<KArg>( k: KArg ) -> AccountInfo<<T as Config>::Nonce, <T as Config>::AccountData>where KArg: EncodeLike<<T as Config>::AccountId>,
An auto-generated getter for Account.
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn block_weight() -> PerDispatchClass<Weight>
pub fn block_weight() -> PerDispatchClass<Weight>
An auto-generated getter for BlockWeight.
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn block_number(
) -> <<<T as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
pub fn block_number( ) -> <<<T as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
An auto-generated getter for Number.
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn parent_hash() -> <T as Config>::Hash
pub fn parent_hash() -> <T as Config>::Hash
An auto-generated getter for ParentHash.
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn event_count() -> u32
pub fn event_count() -> u32
An auto-generated getter for EventCount.
impl<T> Pallet<T>where
T: Config,
impl<T> Pallet<T>where T: Config,
pub fn account_exists(who: &<T as Config>::AccountId) -> bool
pub fn update_code_in_storage(code: &[u8])
pub fn update_code_in_storage(code: &[u8])
Write code to the storage and emit related events and digest items.
Note this function almost never should be used directly. It is exposed
for OnSetCode implementations that defer actual code being written to
the storage (for instance in case of parachains).
pub fn inc_ref(who: &<T as Config>::AccountId)
👎Deprecated: Use inc_consumers instead
pub fn inc_ref(who: &<T as Config>::AccountId)
inc_consumers insteadIncrement the reference counter on an account.
pub fn dec_ref(who: &<T as Config>::AccountId)
👎Deprecated: Use dec_consumers instead
pub fn dec_ref(who: &<T as Config>::AccountId)
dec_consumers insteadDecrement the reference counter on an account. This MUST only be done once for every time
you called inc_consumers on who.
pub fn refs(who: &<T as Config>::AccountId) -> u32
👎Deprecated: Use consumers instead
pub fn refs(who: &<T as Config>::AccountId) -> u32
consumers insteadThe number of outstanding references for the account who.
pub fn allow_death(who: &<T as Config>::AccountId) -> bool
👎Deprecated: Use !is_provider_required instead
pub fn allow_death(who: &<T as Config>::AccountId) -> bool
!is_provider_required insteadTrue if the account has no outstanding references.
pub fn inc_providers(who: &<T as Config>::AccountId) -> IncRefStatus
pub fn inc_providers(who: &<T as Config>::AccountId) -> IncRefStatus
Increment the provider reference counter on an account.
pub fn dec_providers(
who: &<T as Config>::AccountId
) -> Result<DecRefStatus, DispatchError>
pub fn dec_providers( who: &<T as Config>::AccountId ) -> Result<DecRefStatus, DispatchError>
Decrement the provider reference counter on an account.
This MUST only be done once for every time you called inc_providers on who.
pub fn inc_sufficients(who: &<T as Config>::AccountId) -> IncRefStatus
pub fn inc_sufficients(who: &<T as Config>::AccountId) -> IncRefStatus
Increment the self-sufficient reference counter on an account.
pub fn dec_sufficients(who: &<T as Config>::AccountId) -> DecRefStatus
pub fn dec_sufficients(who: &<T as Config>::AccountId) -> DecRefStatus
Decrement the sufficients reference counter on an account.
This MUST only be done once for every time you called inc_sufficients on who.
pub fn providers(who: &<T as Config>::AccountId) -> u32
pub fn providers(who: &<T as Config>::AccountId) -> u32
The number of outstanding provider references for the account who.
pub fn sufficients(who: &<T as Config>::AccountId) -> u32
pub fn sufficients(who: &<T as Config>::AccountId) -> u32
The number of outstanding sufficient references for the account who.
pub fn reference_count(who: &<T as Config>::AccountId) -> u32
pub fn reference_count(who: &<T as Config>::AccountId) -> u32
The number of outstanding provider and sufficient references for the account who.
pub fn inc_consumers(
who: &<T as Config>::AccountId
) -> Result<(), DispatchError>
pub fn inc_consumers( who: &<T as Config>::AccountId ) -> Result<(), DispatchError>
Increment the reference counter on an account.
The account who’s providers must be non-zero and the current number of consumers must
be less than MaxConsumers::max_consumers() or this will return an error.
pub fn inc_consumers_without_limit(
who: &<T as Config>::AccountId
) -> Result<(), DispatchError>
pub fn inc_consumers_without_limit( who: &<T as Config>::AccountId ) -> Result<(), DispatchError>
Increment the reference counter on an account, ignoring the MaxConsumers limits.
The account who’s providers must be non-zero or this will return an error.
pub fn dec_consumers(who: &<T as Config>::AccountId)
pub fn dec_consumers(who: &<T as Config>::AccountId)
Decrement the reference counter on an account. This MUST only be done once for every time
you called inc_consumers on who.
pub fn consumers(who: &<T as Config>::AccountId) -> u32
pub fn consumers(who: &<T as Config>::AccountId) -> u32
The number of outstanding references for the account who.
pub fn is_provider_required(who: &<T as Config>::AccountId) -> bool
pub fn is_provider_required(who: &<T as Config>::AccountId) -> bool
True if the account has some outstanding consumer references.
pub fn can_dec_provider(who: &<T as Config>::AccountId) -> bool
pub fn can_dec_provider(who: &<T as Config>::AccountId) -> bool
True if the account has no outstanding consumer references or more than one provider.
pub fn can_accrue_consumers(who: &<T as Config>::AccountId, amount: u32) -> bool
pub fn can_accrue_consumers(who: &<T as Config>::AccountId, amount: u32) -> bool
True if the account has at least one provider reference and adding amount consumer
references would not take it above the the maximum.
pub fn can_inc_consumer(who: &<T as Config>::AccountId) -> bool
pub fn can_inc_consumer(who: &<T as Config>::AccountId) -> bool
True if the account has at least one provider reference and fewer consumer references than the maximum.
pub fn deposit_event(event: impl Into<<T as Config>::RuntimeEvent>)
pub fn deposit_event(event: impl Into<<T as Config>::RuntimeEvent>)
Deposits an event into this block’s event record.
NOTE: Events not registered at the genesis block and quietly omitted.
pub fn deposit_event_indexed(
topics: &[<T as Config>::Hash],
event: <T as Config>::RuntimeEvent
)
pub fn deposit_event_indexed( topics: &[<T as Config>::Hash], event: <T as Config>::RuntimeEvent )
Deposits an event into this block’s event record adding this event to the corresponding topic indexes.
This will update storage entries that correspond to the specified topics. It is expected that light-clients could subscribe to this topics.
NOTE: Events not registered at the genesis block and not(feature = "std") and quietly
omitted. But, in testing (feature = "std") events are deposited normally.
pub fn extrinsic_index() -> Option<u32>
pub fn extrinsic_index() -> Option<u32>
Gets the index of extrinsic that is currently executing.
pub fn extrinsic_count() -> u32
pub fn extrinsic_count() -> u32
Gets extrinsics count.
pub fn all_extrinsics_len() -> u32
pub fn register_extra_weight_unchecked(weight: Weight, class: DispatchClass)
pub fn register_extra_weight_unchecked(weight: Weight, class: DispatchClass)
Inform the system pallet of some additional weight that should be accounted for, in the current block.
NOTE: use with extra care; this function is made public only be used for certain pallets
that need it. A runtime that does not have dynamic calls should never need this and should
stick to static weights. A typical use case for this is inner calls or smart contract calls.
Furthermore, it only makes sense to use this when it is presumably cheap to provide the
argument weight; In other words, if this function is to be used to account for some
unknown, user provided call’s weight, it would only make sense to use it if you are sure you
can rapidly compute the weight of the inner call.
Even more dangerous is to note that this function does NOT take any action, if the new sum of block weight is more than the block weight limit. This is what the unchecked.
Another potential use-case could be for the on_initialize and on_finalize hooks.
pub fn initialize(
number: &<<<T as Config>::Block as HeaderProvider>::HeaderT as Header>::Number,
parent_hash: &<T as Config>::Hash,
digest: &Digest
)
pub fn initialize( number: &<<<T as Config>::Block as HeaderProvider>::HeaderT as Header>::Number, parent_hash: &<T as Config>::Hash, digest: &Digest )
Start the execution of a particular block.
pub fn finalize() -> <<T as Config>::Block as HeaderProvider>::HeaderT
pub fn finalize() -> <<T as Config>::Block as HeaderProvider>::HeaderT
Remove temporary “environment” entries in storage, compute the storage root and return the resulting header for this block.
pub fn deposit_log(item: DigestItem)
pub fn deposit_log(item: DigestItem)
Deposits a log and ensures it matches the block’s log data.
pub fn externalities() -> TestExternalities<Blake2Hasher>
pub fn externalities() -> TestExternalities<Blake2Hasher>
Get the basic externalities for this pallet, useful for tests.
pub fn events(
) -> Vec<EventRecord<<T as Config>::RuntimeEvent, <T as Config>::Hash>, Global>
pub fn events( ) -> Vec<EventRecord<<T as Config>::RuntimeEvent, <T as Config>::Hash>, Global>
Get the current events deposited by the runtime.
NOTE: This should only be used in tests. Reading events from the runtime can have a large impact on the PoV size of a block. Users should use alternative and well bounded storage items for any behavior like this.
NOTE: Events not registered at the genesis block and quietly omitted.
pub fn event_no_consensus(index: usize) -> Option<<T as Config>::RuntimeEvent>
pub fn event_no_consensus(index: usize) -> Option<<T as Config>::RuntimeEvent>
Get a single event at specified index.
Should only be called if you know what you are doing and outside of the runtime block execution else it can have a large impact on the PoV size of a block.
pub fn read_events_no_consensus(
) -> impl Iterator<Item = Box<EventRecord<<T as Config>::RuntimeEvent, <T as Config>::Hash>, Global>>
pub fn read_events_no_consensus( ) -> impl Iterator<Item = Box<EventRecord<<T as Config>::RuntimeEvent, <T as Config>::Hash>, Global>>
Get the current events deposited by the runtime.
Should only be called if you know what you are doing and outside of the runtime block execution else it can have a large impact on the PoV size of a block.
pub fn read_events_for_pallet<E>() -> Vec<E, Global>where
<T as Config>::RuntimeEvent: TryInto<E>,
pub fn read_events_for_pallet<E>() -> Vec<E, Global>where <T as Config>::RuntimeEvent: TryInto<E>,
Read and return the events of a specific pallet, as denoted by E.
This is useful for a pallet that wishes to read only the events it has deposited into
frame_system using the standard fn deposit_event.
pub fn set_block_number(
n: <<<T as Config>::Block as HeaderProvider>::HeaderT as Header>::Number
)
pub fn set_block_number( n: <<<T as Config>::Block as HeaderProvider>::HeaderT as Header>::Number )
Set the block number to something in particular. Can be used as an alternative to
initialize for tests that don’t need to bother with the other environment entries.
pub fn set_extrinsic_index(extrinsic_index: u32)
pub fn set_extrinsic_index(extrinsic_index: u32)
Sets the index of extrinsic that is currently executing.
pub fn set_parent_hash(n: <T as Config>::Hash)
pub fn set_parent_hash(n: <T as Config>::Hash)
Set the parent hash number to something in particular. Can be used as an alternative to
initialize for tests that don’t need to bother with the other environment entries.
pub fn set_block_consumed_resources(weight: Weight, len: usize)
pub fn set_block_consumed_resources(weight: Weight, len: usize)
Set the current block weight. This should only be used in some integration tests.
pub fn reset_events()
pub fn reset_events()
Reset events.
This needs to be used in prior calling initialize for each new block
to clear events from previous block.
pub fn assert_has_event(event: <T as Config>::RuntimeEvent)
pub fn assert_has_event(event: <T as Config>::RuntimeEvent)
Assert the given event exists.
NOTE: Events not registered at the genesis block and quietly omitted.
pub fn assert_last_event(event: <T as Config>::RuntimeEvent)
pub fn assert_last_event(event: <T as Config>::RuntimeEvent)
Assert the last event equal to the given event.
NOTE: Events not registered at the genesis block and quietly omitted.
pub fn runtime_version() -> RuntimeVersion
pub fn runtime_version() -> RuntimeVersion
Return the chain’s current runtime version.
pub fn account_nonce(
who: impl EncodeLike<<T as Config>::AccountId>
) -> <T as Config>::Nonce
pub fn account_nonce( who: impl EncodeLike<<T as Config>::AccountId> ) -> <T as Config>::Nonce
Retrieve the account transaction counter from storage.
pub fn inc_account_nonce(who: impl EncodeLike<<T as Config>::AccountId>)
pub fn inc_account_nonce(who: impl EncodeLike<<T as Config>::AccountId>)
Increment a particular account’s nonce by 1.
pub fn note_extrinsic(encoded_xt: Vec<u8, Global>)
pub fn note_extrinsic(encoded_xt: Vec<u8, Global>)
Note what the extrinsic data of the current extrinsic index is.
This is required to be called before applying an extrinsic. The data will used
in Self::finalize to calculate the correct extrinsics root.
pub fn note_applied_extrinsic(
r: &Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>,
info: DispatchInfo
)
pub fn note_applied_extrinsic( r: &Result<PostDispatchInfo, DispatchErrorWithPostInfo<PostDispatchInfo>>, info: DispatchInfo )
To be called immediately after an extrinsic has been applied.
Emits an ExtrinsicSuccess or ExtrinsicFailed event depending on the outcome.
The emitted event contains the post-dispatch corrected weight including
the base-weight for its dispatch class.
pub fn note_finished_extrinsics()
pub fn note_finished_extrinsics()
To be called immediately after note_applied_extrinsic of the last extrinsic of the block
has been called.
pub fn note_finished_initialize()
pub fn note_finished_initialize()
To be called immediately after finishing the initialization of the block
(e.g., called on_initialize for all pallets).
pub fn on_created_account(
who: <T as Config>::AccountId,
_a: &mut AccountInfo<<T as Config>::Nonce, <T as Config>::AccountData>
)
pub fn on_created_account( who: <T as Config>::AccountId, _a: &mut AccountInfo<<T as Config>::Nonce, <T as Config>::AccountData> )
An account is being created.
pub fn can_set_code(code: &[u8]) -> Result<(), DispatchError>
pub fn can_set_code(code: &[u8]) -> Result<(), DispatchError>
Determine whether or not it is possible to update the code.
Checks the given code if it is a valid runtime wasm blob by instantianting it and extracting the runtime version of it. It checks that the runtime version of the old and new runtime has the same spec name and that the spec version is increasing.